Module beamlit.models.serverless_config
=======================================

Classes
-------

`ServerlessConfig(last_pod_retention_period: beamlit.types.Unset | str = <beamlit.types.Unset object>, max_num_replicas: beamlit.types.Unset | int = <beamlit.types.Unset object>, metric: beamlit.types.Unset | str = <beamlit.types.Unset object>, min_num_replicas: beamlit.types.Unset | int = <beamlit.types.Unset object>, scale_down_delay: beamlit.types.Unset | str = <beamlit.types.Unset object>, scale_up_minimum: beamlit.types.Unset | int = <beamlit.types.Unset object>, stable_window: beamlit.types.Unset | str = <beamlit.types.Unset object>, target: beamlit.types.Unset | str = <beamlit.types.Unset object>)`
:   Configuration for a serverless deployment
    
    Attributes:
        last_pod_retention_period (Union[Unset, str]): The minimum amount of time that the last replica will remain
            active AFTER a scale-to-zero decision is made
        max_num_replicas (Union[Unset, int]): The maximum number of replicas for the deployment.
        metric (Union[Unset, str]): Metric watched to make scaling decisions. Can be "cpu" or "memory" or "rps" or
            "concurrency"
        min_num_replicas (Union[Unset, int]): The minimum number of replicas for the deployment. Can be 0 or 1 (in which
            case the deployment is always running in at least one location).
        scale_down_delay (Union[Unset, str]): The time window which must pass at reduced concurrency before a scale-down
            decision is applied. This can be useful, for example, to keep containers around for a configurable duration to
            avoid a cold start penalty if new requests come in.
        scale_up_minimum (Union[Unset, int]): The minimum number of replicas that will be created when the deployment
            scales up from zero.
        stable_window (Union[Unset, str]): The sliding time window over which metrics are averaged to provide the input
            for scaling decisions
        target (Union[Unset, str]): Target value for the watched metric
    
    Method generated by attrs for class ServerlessConfig.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `last_pod_retention_period: beamlit.types.Unset | str`
    :

    `max_num_replicas: beamlit.types.Unset | int`
    :

    `metric: beamlit.types.Unset | str`
    :

    `min_num_replicas: beamlit.types.Unset | int`
    :

    `scale_down_delay: beamlit.types.Unset | str`
    :

    `scale_up_minimum: beamlit.types.Unset | int`
    :

    `stable_window: beamlit.types.Unset | str`
    :

    `target: beamlit.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :